@@ -62,6 +62,9 @@ zh_CN = {
     "authenticated-as-controller-notification": "{}成为了管理员",
     "created-controlled-room-notification": "已创建房间：'{}' ，密码是'{}'。请保存好以上信息以备用！\n\n只有房主或管理员可以暂停，继续播放，跳转播放，改变播放列表。每个人都与房主或管理员的播放进度同步。\n\n最近观看过的人都可加入'{}'房间，但只有房主或管理员在加入'{}'房间时才会自动认证为管理员。",  # RoomName, operatorPassword, roomName, roomName:operatorPassword
 
+    "other-set-as-ready-notification": "{} was set as ready by {}",  # User set as ready, user who set them as ready # TODO: Translate
+    "other-set-as-not-ready-notification": "{} was set as not ready by {}", # User set as not ready, user who set them as not ready # TODO: Translate
+
     "file-different-notification": "您正在播放的视频与{}不一致",  # User
     "file-differences-notification": "你们播放的视频文件{}不一致",  # Differences
     "room-file-differences": "播放文件不同点：{}",  # File differences (filename, size, and/or duration)
@@ -98,6 +101,8 @@ zh_CN = {
     "commandlist-notification/offset": "\to[+-]duration - 将本地的播放偏移量设置为给定时长（输入格式可为秒或分：秒），您的本地播放进度将与服务器不一致，因此极不推荐使用该设置",
     "commandlist-notification/help": "\th - 帮助菜单",
     "commandlist-notification/toggle": "\tt - 准备/取消准备",
+    "commandlist-notification/setready": "\tsr [name] - sets user as ready",  # TODO: Translate
+    "commandlist-notification/setnotready": "\tsn [name] - sets user as not ready",  # TODO: Translate
     "commandlist-notification/create": "\tc [name] - 以给定房间名创建一个由您管理的房间",
     "commandlist-notification/auth": "\ta [password] - 用给定密码来认证为管理员",
     "commandlist-notification/chat": "\tch [message] - 发送聊天信息",
@@ -133,7 +138,7 @@ zh_CN = {
     "hostname-empty-error": "主机名不能是空的",
     "empty-error": "{}不能是空的",  # Configuration
     "media-player-error": "媒体播放器错误：\"{}\"",  # Error line
-    "unable-import-gui-error": "无法导入GUI库。如果你没有安装PySide，GUI则无法工作，请安装PySide。",
+    "unable-import-gui-error": "无法导入GUI库。如果你没有安装PySide，GUI则无法工作，请安装PySide。 If you want to run Syncplay in console mode then run it with the --no-gui command line switch. See https://syncplay.pl/guide/ for more details.", # TODO: Translate end of message and update second sentence to be a translation of "You need to have the correct version of PySide installed for the GUI to work."
     "unable-import-twisted-error": "无法导入Twisted。请安装Twisted v16.4.0或更高版本。",
 
     "arguments-missing-error": "缺少一些必要的参数，使用--help命令查看详细信息",
@@ -158,6 +163,7 @@ zh_CN = {
     "feature-chat": "聊天",  # used for not-supported-by-server-error
     "feature-readiness": "准备状态",  # used for not-supported-by-server-error
     "feature-managedRooms": "房间管理",  # used for not-supported-by-server-error
+    "feature-setOthersReadiness": "readiness override",  # used for not-supported-by-server-error # TODO: Translate
 
     "not-supported-by-server-error": "该服务器不支持{}功能",  # feature
     "shared-playlists-not-supported-by-server-error": "服务器可能不支持共享播放列表的功能。为确保其正常运行，需要一个运行Syncplay {}以上版本的服务器，但服务器是运行Syncplay {}的。",  # minVersion, serverVersion
@@ -167,7 +173,8 @@ zh_CN = {
     "invalid-offset-value": "无效的偏移值",
 
     "switch-file-not-found-error": "无法切换到视频文件'{0}'。Syncplay只在指定的媒体目录中查找文件。",  # File not found
-    "folder-search-timeout-error": "在媒体目录中搜索媒体文件时，由于在'{}'中搜索时间过长而中止。如果你在要搜索的媒体文件夹列表中选择了一个子文件夹过多的文件夹，就会出现这种情况。为了使自动文件切换再次工作，请在菜单栏中选择\"文件->设置媒体目录\"，并删除这个目录或用一个适当的子文件夹替换它。如果这个文件夹实际上是适当的，那么你可以通过选择\"文件->设置媒体目录\"并按\"确定\"来重新启用它。",  # Folder
+    "folder-search-timeout-error": "在媒体目录中搜索媒体文件时，由于在'{}'中搜索时间过长而中止 (after having processed the first {} files)。如果你在要搜索的媒体文件夹列表中选择了一个子文件夹过多的文件夹，就会出现这种情况。为了使自动文件切换再次工作，请在菜单栏中选择\"文件->设置媒体目录\"，并删除这个目录或用一个适当的子文件夹替换它。如果这个文件夹实际上是适当的，那么你可以通过选择\"文件->设置媒体目录\"并按\"确定\"来重新启用它。",  # Folder, Files processed - TODO: Update translation (refer back to original English text)
+    "folder-search-timeout-warning": "Warning: It has taken {} seconds to scan {:,} files in the folder '{}'. This will occur if you select a folder with too many sub-folders in your list of media folders to search through or if there are too many files to process.",  # Folder, Files processed. Note: {:,} is {} but with added commas seprators. TODO: Translate
     "folder-search-first-file-timeout-error": "搜索'{}'中的媒体文件时，由于访问该目录的时间太长而被中止。如果该目录位于网络驱动器，或者如果你配置了你的驱动器在一段时间不活动后停止工作，就会发生这种情况。为了能够自动切换播放文件，请进入\"文件->设置媒体目录\"，并删除该目录或解决这个问题（还可尝试其他解决方式，例如，改变省电设置）。",  # Folder
     "added-file-not-in-media-directory-error": "你在'{}'中加载了一个文件，该媒体目录尚未保存。你可以通过选择菜单栏中的\"文件->设置媒体目录\"将其保存为指定媒体目录。",  # Folder
     "no-media-directories-error": "没有设置媒体目录。为了使共享播放列表和文件切换功能正常工作，请选择\"文件->设置媒体目录\"，并指定Syncplay应该在哪里寻找媒体文件。",
@@ -474,6 +481,8 @@ zh_CN = {
     # Server messages to client
     "new-syncplay-available-motd-message": "您正在使用Syncplay {}版本，但已有较新的版本可从https://syncplay.pl下载。",  # ClientVersion
     "persistent-rooms-notice": "NOTICE: This server uses persistent rooms, which means that the playlist information is stored between playback sessions. If you want to create a room where information is not saved then put -temp at the end of the room name.", # NOTE: Do not translate the word -temp
+    "ready-chat-message": "I have set {} as ready.",  # User # TODO: Translate
+    "not-ready-chat-message": "I have set {} as not ready.",  # User # TODO: Translate
 
     # Server notifications
     "welcome-server-notification": "欢迎使用Syncplay服务端，当前版本{0}",  # version
@@ -500,6 +509,10 @@ zh_CN = {
     "server-startTLS-argument": "使用提供的路径中的证书文件启用TLS连接",
     "server-messed-up-motd-unescaped-placeholders": "每日信息中有未转义的占位符。所有 $ 字符应当重复两遍 ($$).",
     "server-messed-up-motd-too-long": "每日信息过长 - 最大{}个chars, 给出的长度{}",
+    "server-listen-only-on-ipv4": "Listen only on IPv4 when starting the server.",
+    "server-listen-only-on-ipv6": "Listen only on IPv6 when starting the server.",
+    "server-interface-ipv4": "The IP address to bind to for IPv4. Leaving it empty defaults to using all.",
+    "server-interface-ipv6": "The IP address to bind to for IPv6. Leaving it empty defaults to using all.",
 
     # Server errors
     "unknown-command-server-error": "未知命令 {}",  # message
@@ -534,6 +547,9 @@ zh_CN = {
     "openusersstream-menu-label": "打开{}的媒体流",  # [username]'s
     "openusersfile-menu-label": "打开{}的文件",  # [username]'s
 
+    "setasready-menu-label": "Set {} as ready",  # [Username] # TODO: Translate
+    "setasnotready-menu-label": "Set {} as not ready",  # [Username] # TODO: Translate
+
     "playlist-instruction-item-message": "把文件拖到这里，就可以把它添加到共享播放列表中。",
     "sharedplaylistenabled-tooltip": "房间管理员可以将文件添加到共享播放列表中，以方便大家观看同样的东西。可以在其他设置中配置媒体目录。",
 
