@@ -283,6 +283,7 @@ class MpcHcApi:
             pCDS = ctypes.cast(lparam, self.__PCOPYDATASTRUCT)
             # print "API:\tin>\t 0x%X\t" % int(pCDS.contents.dwData), ctypes.wstring_at(pCDS.contents.lpData)
             self.__mpcApi.handleCommand(pCDS.contents.dwData, ctypes.wstring_at(pCDS.contents.lpData))
+            return 0
 
         def SendCommand(self, cmd, message=''):
             # print "API:\t<out\t 0x%X\t" % int(cmd), message
@@ -406,8 +407,8 @@ class MPCHCAPIPlayer(BasePlayer):
 
     def openFile(self, filePath, resetPosition=False):
         self._mpcApi.openFile(filePath)
-        if resetPosition:
-            self.setPosition(0)
+        if resetPosition and self._mpcApi.filePlaying:
+            self.setPosition(0, resetPosition=True)
 
     def displayMessage(
         self, message,
@@ -429,9 +430,11 @@ class MPCHCAPIPlayer(BasePlayer):
         pass
 
     @retry(MpcHcApi.PlayerNotReadyException, constants.MPC_MAX_RETRIES, constants.MPC_RETRY_WAIT_TIME, 1)
-    def setPosition(self, value):
+    def setPosition(self, value, resetPosition=False):
         if self._mpcApi.filePlaying:
             self._mpcApi.seek(value)
+        elif resetPosition:
+            raise MpcHcApi.PlayerNotReadyException()
 
     def __getPosition(self):
         self.__positionUpdate.clear()
@@ -520,4 +523,4 @@ class MPCHCAPIPlayer(BasePlayer):
                 return path
             elif os.path.isfile(path + "\\" +  mpc_executable_filename):
                 path += "\\" + mpc_executable_filename
-                return path
\ No newline at end of file
+                return path
