@@ -50,6 +50,24 @@ class VLCProtocol(LineReceiver):
         self.factory.connected = False
 
 class VLCClientFactory(ReconnectingClientFactory):
+
+    # http://twistedmatrix.com/documents/current/api/twisted.internet.protocol.ReconnectingClientFactory.html
+    #
+    initialDelay = 0.3
+    maxDelay = 0.45
+    maxRetries = 50
+
+    def startedConnecting(self, connector):
+        self._playerController._client.ui.showDebugMessage("Starting to connect to VLC...")
+
+    def clientConnectionLost(self, connector, reason):
+        self._playerController._client.ui.showDebugMessage("Connection to VLC lost: {}".format(reason))
+        ReconnectingClientFactory.clientConnectionLost(self, connector, reason)
+
+    def clientConnectionFailed(self, connector, reason):
+        self._playerController._client.ui.showDebugMessage("Connection to VLC failed: {}".format(reason))
+        ReconnectingClientFactory.clientConnectionFailed(self, connector, reason)
+
     def __init__(self, playerController, vlcHasResponded, vlcLaunchedTime, vlcProcess):
         self._playerController = playerController
         self._process = vlcProcess
@@ -279,7 +297,7 @@ class VlcPlayer(BasePlayer):
                     # value = value.decode('utf-8')
                 self._filepath = value
             self._pathAsk.set()
-        elif name == "duration":
+        elif name == "duration" or name == "duration-change":
             if value == "no-input":
                 self._duration = 0
             elif value == "invalid-32-bit-value":
@@ -288,6 +306,11 @@ class VlcPlayer(BasePlayer):
             else:
                 self._duration = float(value.replace(",", "."))
             self._durationAsk.set()
+            if name == "duration-change":
+                self._filechanged = True
+                t = threading.Thread(target=self._onFileUpdate)
+                t.setDaemon(True)
+                t.start()
         elif name == "playstate":
             self._paused = bool(value != 'playing') if (value != "no-input" and self._filechanged == False) else self._client.getGlobalPaused()
             diff = time.time() - self._lastVLCPositionUpdate if self._lastVLCPositionUpdate else 0
@@ -464,10 +487,14 @@ class VlcPlayer(BasePlayer):
 
             call.extend(self.__playerController.SLAVE_ARGS)
             if args:
-                call.extend(args)
+                for arg in args:
+                    if "=" in arg and "\"" in arg:
+                        (argName, argValue) = arg.split("=", 1)
+                        if argValue.startswith("\"") and argValue.endswith("\""):
+                            arg = argName + "=" + argValue[1:-1]
+                    call.extend([arg])
 
             self._vlcVersion = None
-
             if isWindows() and getattr(sys, 'frozen', '') and getattr(sys, '_MEIPASS', '') is not None:  # Needed for pyinstaller --onefile bundle
                 self.__process = subprocess.Popen(
                     call, stdin=subprocess.PIPE, stderr=subprocess.PIPE, stdout=subprocess.PIPE,
