@@ -1,5 +1,5 @@
-
 import ast
+import atexit
 import datetime
 import hashlib
 import itertools
@@ -10,12 +10,13 @@ import re
 import string
 import subprocess
 import sys
+import tempfile
 import time
 import traceback
-import unicodedata
 import urllib.error
 import urllib.parse
 import urllib.request
+from pathlib import Path
 
 from syncplay import constants
 from syncplay.messages import getMessage
@@ -39,6 +40,27 @@ def isBSD():
     return constants.OS_BSD in sys.platform or sys.platform.startswith(constants.OS_DRAGONFLY)
 
 
+def isWindowsConsole():
+    return os.path.basename(sys.executable) == "SyncplayConsole.exe"
+
+
+def getRuntimeDir():
+    cachedPath = getattr(getRuntimeDir, "cachedPath", None)
+    if cachedPath is not None:
+        return cachedPath
+
+    baseDir = None
+    if not isWindows() and not isMacOS():
+        baseDir = os.getenv("XDG_RUNTIME_DIR", None)
+
+    tmp = tempfile.TemporaryDirectory(prefix="syncplay-", dir=baseDir)
+    atexit.register(tmp.cleanup)
+
+    o = Path(tmp.name)
+    setattr(getRuntimeDir, "cachedPath", o)
+    return o
+
+
 def retry(ExceptionToCheck, tries=4, delay=3, backoff=2, logger=None):
     """Retry calling the decorated function using an exponential backoff.
 
@@ -82,6 +104,8 @@ def retry(ExceptionToCheck, tries=4, delay=3, backoff=2, logger=None):
 
 
 def parseTime(timeStr):
+    if ":" not in timeStr:
+        return float(timeStr)
     regex = re.compile(constants.PARSE_TIME_REGEX)
     parts = regex.match(timeStr)
     if not parts:
@@ -188,6 +212,10 @@ def limitedPowerset(s, minLength):
     return itertools.chain.from_iterable(itertools.combinations(s, r) for r in range(len(s), minLength, -1))
 
 
+def parseCommandLineString(s):
+    arsToReturn = re.findall(constants.ARGUMENT_SPLIT_REGEX, s)
+    return arsToReturn
+
 def blackholeStdoutForFrozenWindow():
     if getattr(sys, 'frozen', '') == "windows_exe":
         class Stderr(object):
@@ -204,7 +232,8 @@ def blackholeStdoutForFrozenWindow():
                     self._file = open(path, 'a', encoding='utf-8')
                     # TODO: Handle errors.
                 if self._file is not None:
-                    self._file.write(text)
+                    if not (text.startswith("<frozen zipimport>") and "UserWarning:" in text):
+                        self._file.write(text)
                     self._file.flush()
 
             def flush(self):
@@ -226,6 +255,28 @@ def blackholeStdoutForFrozenWindow():
         sys.stdout = Blackhole()
         del Blackhole
 
+    elif isWindowsConsole():
+        class Blackhole(object):
+            softspace = 0
+
+            def write(self, text):
+                pass
+
+            def flush(self):
+                pass
+
+        class Stderr(object):
+            softspace = 0
+            _file = None
+            _error = None
+
+            def flush(self):
+                if self._file is not None:
+                    self._file.flush()
+
+        sys.stderr = Blackhole()
+        del Blackhole
+
 
 def truncateText(unicodeText, maxLength):
     try:
@@ -276,7 +327,7 @@ def stripfilename(filename, stripURL):
 def stripRoomName(RoomName):
     if RoomName:
         try:
-            return re.sub(constants.ROOM_NAME_STRIP_REGEX, "\g<roomnamebase>", RoomName)
+            return re.sub(constants.ROOM_NAME_STRIP_REGEX, r"\g<roomnamebase>", RoomName)
         except IndexError:
             return RoomName
     else:
@@ -454,8 +505,8 @@ def getListOfPublicServers():
 
 
 class RoomPasswordProvider(object):
-    CONTROLLED_ROOM_REGEX = re.compile("^\+(.*):(\w{12})$")
-    PASSWORD_REGEX = re.compile("[A-Z]{2}-\d{3}-\d{3}")
+    CONTROLLED_ROOM_REGEX = re.compile(r"^\+(.*):(\w{12})$")
+    PASSWORD_REGEX = re.compile(r"[A-Z]{2}-\d{3}-\d{3}")
 
     @staticmethod
     def isControlledRoom(roomName):
